@@ -3,6 +3,7 @@ from typing import Any, Dict, List
 from . import DataSchema, TreeSchemaSerializer, TreeSchemaUser
 from .tags import get_tags_added
 from ..exceptions import DataAssetDoesNotExist
+from ..integrations.dbt import DbtManager
 
 
 class DataStore(TreeSchemaSerializer):
@@ -39,6 +40,7 @@ class DataStore(TreeSchemaSerializer):
         self._schemas_by_name = {}
         self._schemas_retrieved = False
         super(DataStore, self).__init__(data_store_inputs)
+        self.dbt = DbtManager(self.id)
         
     def _get_self_by_id(self):
         raw_resp = self.client.get_data_store_by_id(self.id)
@@ -73,7 +75,9 @@ class DataStore(TreeSchemaSerializer):
     def _create(self):
         data_store = {}
         if not self._is_validated:
-            data_store_raw = self.client.create_data_store(self._raw_inputs)
+            data_store_raw = self.client.create_data_store(
+                self._simplify_user_raw_inputs(self._raw_inputs)
+            )
             data_store = data_store_raw.get('data_store')
             if data_store:
                 self._is_validated = True
@@ -208,3 +212,4 @@ class DataStore(TreeSchemaSerializer):
         return deleted
 
 
+    
\ No newline at end of file
